@@ -1,30 +1,30 @@
 #!/usr/bin/python3
 #
-# The Qubes OS Project, http://www.qubes-os.org
+# The Qubes OS Project, https://www.qubes-os.org/
 #
 # Copyright (C) 2020  Marta Marczykowska-Górecka
 # <marmarta@invisiblethingslab.com>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License along
-# with this program; if not, see <http://www.gnu.org/licenses/>.
-#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 import os
 import sys
 import subprocess
 
-from PyQt5 import QtCore, QtWidgets, QtGui  # pylint: disable=import-error
+from PyQt6 import QtCore, QtWidgets, QtGui  # pylint: disable=import-error
 
 import qubesadmin
 import qubesadmin.tools
@@ -35,6 +35,10 @@ from . import utils
 
 from .ui_clonevmdlg import Ui_CloneVMDlg  # pylint: disable=import-error
 
+# this is needed for icons to actually work
+# pylint: disable=unused-import, no-name-in-module
+from . import resources
+
 
 class CloneVMDlg(QtWidgets.QDialog, Ui_CloneVMDlg):
     def __init__(self, qtapp, app, parent=None, src_vm=None):
@@ -73,8 +77,11 @@ class CloneVMDlg(QtWidgets.QDialog, Ui_CloneVMDlg):
 
         self.set_clone_name()
 
-        self.name.setValidator(QtGui.QRegExpValidator(
-            QtCore.QRegExp("[a-zA-Z0-9_-]*", QtCore.Qt.CaseInsensitive), None))
+        self.name.setValidator(QtGui.QRegularExpressionValidator(
+            QtCore.QRegularExpression(
+                "[a-zA-Z0-9_-]*",
+                QtCore.QRegularExpression.PatternOption.CaseInsensitiveOption),
+            None))
         self.name.selectAll()
         self.name.setFocus()
 
@@ -183,4 +190,4 @@ def main(args=None):
         "appname", 'Clone qube'))
 
     dialog = CloneVMDlg(qtapp, args.app, src_vm=src_vm)
-    dialog.exec_()
+    dialog.exec()
